package de.intevation.flys.artifacts.states;

import org.apache.log4j.Logger;

import org.w3c.dom.Element;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.CallMeta;

import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifactdatabase.ProtocolUtils;

import de.intevation.flys.artifacts.resources.Resources;

/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ScenarioSelect extends DefaultState {

    /** The logger that is used in this class.*/
    private static Logger logger = Logger.getLogger(ScenarioSelect.class);


    public static final String FIELD_MODE = "szenario";

    public static final String SCENARIO_CURRENT   = "scenario.current";
    public static final String SCENARIO_POTENTIEL = "scenario.potentiel";
    public static final String SCENARIO_SCENRAIO  = "scenario.scenario";

    public static final String[] SCENARIOS = {
        SCENARIO_CURRENT,
        SCENARIO_POTENTIEL,
        SCENARIO_SCENRAIO };


    @Override
    protected Element[] createItems(
        XMLUtils.ElementCreator cr,
        Artifact    artifact,
        String      name,
        CallContext context)
    {
        CallMeta meta       = context.getMeta();
        Element[] scenarios = new Element[SCENARIOS.length];

        int i = 0;

        for (String scenario: SCENARIOS) {
            scenarios[i++] = createItem(
                cr, new String[] {
                    Resources.getMsg(meta, scenario, scenario),
                    scenario
                });
        }

        return scenarios;
    }


    protected Element createItem(XMLUtils.ElementCreator cr, Object obj) {
        Element item  = ProtocolUtils.createArtNode(cr, "item", null, null);
        Element label = ProtocolUtils.createArtNode(cr, "label", null, null);
        Element value = ProtocolUtils.createArtNode(cr, "value", null, null);

        String[] arr = (String[]) obj;

        label.setTextContent(arr[0]);
        value.setTextContent(arr[1]);

        item.appendChild(label);
        item.appendChild(value);

        return item;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
